std.log.form


debugcljmacro

(debug data)
(debug context data)
(debug logger context data)
source

deflog-datacljmacro

(deflog-data levels)

creates a standard form given a type

creates a standard form given a type
sourceraw docstring

deflog-errorcljmacro

(deflog-error levels)

creates a standard form given a type

creates a standard form given a type
sourceraw docstring

errorcljmacro

(error exception)
(error context exception)
(error logger context exception)
source

fatalcljmacro

(fatal exception)
(fatal context exception)
(fatal logger context exception)
source

infocljmacro

(info data)
(info context data)
(info logger context data)
source

logcljmacro

(log data)
(log context data)
(log level context data)
(log logger level context data)
(log logger level context data exception)

produces a log

produces a log
sourceraw docstring

log-checkclj

(log-check level)

checks to see if form should be ignored

(log-check :debug) => true

checks to see if form should be ignored

(log-check :debug)
=> true
sourceraw docstring

log-contextclj

(log-context body)

creates a log-context form

(log-context "hello") => seq?

creates a log-context form

(log-context "hello")
=> seq?
sourceraw docstring

log-data-formclj

(log-data-form level)

creates a standard form given a type

creates a standard form given a type
sourceraw docstring

log-error-formclj

(log-error-form level)

creates forms for warn, fatal

creates forms for  `warn`, `fatal`
sourceraw docstring

log-fnclj

(log-fn logger level data exception context)

actual log function for function application

actual log function for function application
sourceraw docstring

log-formclj

(log-form level id form logger context data exception preset)

function for not including log forms on static compilation

function for not including log forms on static compilation
sourceraw docstring

log-function-nameclj

(log-function-name name)

gets the function name

(log-function-name "ns$function_name") => "function-name"

gets the function name

(log-function-name "ns$function_name")
=> "function-name"
sourceraw docstring

log-metaclj

(log-meta form)

gets the metadata information on macroexpand

gets the metadata information on macroexpand
sourceraw docstring

log-runtimeclj

source

log-runtime-rawclj

(log-runtime-raw id ns)

returns the runtime information of the log entry

(set (keys (log-runtime-raw nil "std.log.form-test"))) => #{:log/function :log/method :log/filename}

returns the runtime information of the log entry

(set (keys (log-runtime-raw nil "std.log.form-test")))
=> #{:log/function :log/method :log/filename}
sourceraw docstring

to-contextclj

(to-context context)

converts a string to a log context

(to-context "hello") => #:log{:message "hello"}

converts a string to a log context

(to-context "hello")
=> #:log{:message "hello"}
sourceraw docstring

verbosecljmacro

(verbose data)
(verbose context data)
(verbose logger context data)
source

warncljmacro

(warn data)
(warn context data)
(warn logger context data)
source

with-contextcljmacro

(with-context context & body)

applies a context to the current one

applies a context to the current one
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries