std.log.profile


actioncljmacro

(action body)
(action context body)
(action logger context body)
source

bind-traceclj

(bind-trace trace thunk)

binds a trace id to the log

binds a trace id to the log
sourceraw docstring

blockcljmacro

(block body)
(block context body)
(block logger context body)
source

defmetercljmacro

(defmeter name level preset)

creates a meter macro

creates a meter macro
sourceraw docstring

defspycljmacro

(defspy name level preset)

creates a spy macro

creates a spy macro
sourceraw docstring

item-styleclj

(item-style {:keys [label hide show retain] :as m})

styles the actual log entry

styles the actual log entry
sourceraw docstring

metercljmacro

(meter body)
(meter context body)
(meter logger context body)
source

meter-fnclj

(meter-fn logger thunk level {:console/keys [style] :as context})

constructs a meter function

constructs a meter function
sourceraw docstring

meter-formclj

(meter-form level id form body logger context preset)

helper to the meter macro

helper to the `meter` macro
sourceraw docstring

notecljmacro

(note body)
(note context body)
(note logger context body)
source

on-colorclj

(on-color color)

produces an on-color style for console label

produces an on-color style for console label
sourceraw docstring

on-greyclj

(on-grey color)

produces an on-grey style for console label

produces an on-grey style for console label
sourceraw docstring

on-whiteclj

(on-white color)

produces an on-white style for console label

produces an on-white style for console label
sourceraw docstring

profilecljmacro

(profile body)
(profile context body)
(profile logger context body)
source

sectioncljmacro

(section body)
(section context body)
(section logger context body)
source

showcljmacro

(show body)
(show context body)
(show logger context body)
source

silentcljmacro

(silent body)
(silent context body)
(silent logger context body)
source

spycljmacro

(spy body)
(spy context body)
(spy logger context body)
source

spy-fnclj

(spy-fn logger thunk level context)
(spy-fn logger
        thunk
        level
        context
        {:keys [start-fn wrap-fn write-fn end-fn error-fn] :as hooks})

constructs a spy function with print on start and end

constructs a spy function with print on start and end
sourceraw docstring

spy-formclj

(spy-form level id form body logger context preset)

helper function for the spy macro

helper function for the `spy` macro
sourceraw docstring

statuscljmacro

(status body)
(status context body)
(status logger context body)
source

taskcljmacro

(task body)
(task context body)
(task logger context body)
source

todocljmacro

(todo body)
(todo context body)
(todo logger context body)
source

tracecljmacro

(trace body)
(trace context body)
(trace logger context body)
source

trackcljmacro

(track body)
(track context body)
(track logger context body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries