(deflog-data levels)creates a standard form given a type
creates a standard form given a type
(deflog-error levels)creates a standard form given a type
creates a standard form given a type
(log data)(log context data)(log level context data)(log logger level context data)(log logger level context data exception)produces a log
produces a log
(log-check level)checks to see if form should be ignored
(log-check :debug) => true
checks to see if form should be ignored (log-check :debug) => true
(log-context body)creates a log-context form
(log-context "hello") => seq?
creates a log-context form (log-context "hello") => seq?
(log-data-form level)creates a standard form given a type
creates a standard form given a type
(log-error-form level)creates forms for warn, fatal
creates forms for `warn`, `fatal`
(log-fn logger level data exception context)actual log function for function application
actual log function for function application
(log-form level id form logger context data exception preset)function for not including log forms on static compilation
function for not including log forms on static compilation
(log-function-name name)gets the function name
(log-function-name "ns$function_name") => "function-name"
gets the function name (log-function-name "ns$function_name") => "function-name"
(log-meta form)gets the metadata information on macroexpand
gets the metadata information on macroexpand
(log-runtime-raw id ns)returns the runtime information of the log entry
(set (keys (log-runtime-raw nil "std.log.form-test"))) => #{:log/function :log/method :log/filename}
returns the runtime information of the log entry
(set (keys (log-runtime-raw nil "std.log.form-test")))
=> #{:log/function :log/method :log/filename}(to-context context)converts a string to a log context
(to-context "hello") => #:log{:message "hello"}
converts a string to a log context
(to-context "hello")
=> #:log{:message "hello"}(with-context context & body)applies a context to the current one
applies a context to the current one
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |