(bind-trace trace thunk)binds a trace id to the log
binds a trace id to the log
(defmeter name level preset)creates a meter macro
creates a meter macro
(item-style {:keys [label hide show retain] :as m})styles the actual log entry
styles the actual log entry
(meter-fn logger thunk level {:console/keys [style] :as context})constructs a meter function
constructs a meter function
(meter-form level id form body logger context preset)helper to the meter macro
helper to the `meter` macro
(on-color color)produces an on-color style for console label
produces an on-color style for console label
(on-grey color)produces an on-grey style for console label
produces an on-grey style for console label
(on-white color)produces an on-white style for console label
produces an on-white style for console label
(spy-fn logger thunk level context)(spy-fn logger
thunk
level
context
{:keys [start-fn wrap-fn write-fn end-fn error-fn] :as hooks})constructs a spy function with print on start and end
constructs a spy function with print on start and end
(spy-form level id form body logger context preset)helper function for the spy macro
helper function for the `spy` macro
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |